@@ -24,12 +24,12 @@ from neutron.agent.l3 import dvr_edge_router
 from neutron.agent.l3 import dvr_snat_ns
 from neutron.agent.l3 import legacy_router
 from neutron.agent.linux import iptables_manager
+from neutron.conf.agent.l3 import config as l3_config
 from neutron_lib import constants
 from oslo_config import cfg
 from oslo_utils import uuidutils
 
 from neutron_vpnaas.extensions import vpnaas
-from neutron_vpnaas.services.vpn.device_drivers import fedora_strongswan_ipsec
 from neutron_vpnaas.services.vpn.device_drivers import ipsec as openswan_ipsec
 from neutron_vpnaas.services.vpn.device_drivers import libreswan_ipsec
 from neutron_vpnaas.services.vpn.device_drivers import strongswan_ipsec
@@ -40,6 +40,7 @@ FAKE_HOST = 'fake_host'
 FAKE_ROUTER_ID = _uuid()
 FAKE_IPSEC_SITE_CONNECTION1_ID = _uuid()
 FAKE_IPSEC_SITE_CONNECTION2_ID = _uuid()
+FAKE_VPNSERVICE_ID = _uuid()
 FAKE_IKE_POLICY = {
     'ike_version': 'v1',
     'encryption_algorithm': 'aes-128',
@@ -58,7 +59,7 @@ FAKE_IPSEC_POLICY = {
 }
 
 FAKE_VPN_SERVICE = {
-    'id': _uuid(),
+    'id': FAKE_VPNSERVICE_ID,
     'router_id': FAKE_ROUTER_ID,
     'name': 'myvpn',
     'admin_state_up': True,
@@ -159,12 +160,11 @@ IPV6_NEXT_HOP = '''# To recognize the given IP addresses in this config
     # rightnexthop is not mandatory for ipsec, so no need in ipv6.'''
 
 EXPECTED_OPENSWAN_CONF = """
-# Configuration for myvpn
+# Configuration for %(vpnservice_id)s
 config setup
     nat_traversal=yes
     virtual_private=%(virtual_privates)s
 conn %%default
-    ikelifetime=480m
     keylife=60m
     keyingtries=%%forever
 conn %(conn1_id)s
@@ -219,16 +219,15 @@ STRONGSWAN_AUTH_ESP = 'esp=aes128-sha1-modp1536'
 STRONGSWAN_AUTH_AH = 'ah=sha1-modp1536'
 
 EXPECTED_IPSEC_OPENSWAN_SECRET_CONF = '''
-# Configuration for myvpn
-60.0.0.4 60.0.0.5 : PSK "password"
-60.0.0.4 60.0.0.6 : PSK "password"'''
+# Configuration for %s
+60.0.0.4 60.0.0.5 : PSK 0scGFzc3dvcmQ=
+60.0.0.4 60.0.0.6 : PSK 0scGFzc3dvcmQ=''' % FAKE_VPNSERVICE_ID
 
 EXPECTED_IPSEC_STRONGSWAN_CONF = '''
-# Configuration for myvpn
+# Configuration for %(vpnservice_id)s
 config setup
 
 conn %%default
-        ikelifetime=60m
         keylife=20m
         rekeymargin=3m
         keyingtries=1
@@ -286,11 +285,11 @@ include strongswan.d/*.conf
 '''
 
 EXPECTED_IPSEC_STRONGSWAN_SECRET_CONF = '''
-# Configuration for myvpn
-60.0.0.4 60.0.0.5 : PSK "password"
+# Configuration for %s
+60.0.0.4 60.0.0.5 : PSK 0scGFzc3dvcmQ=
 
-60.0.0.4 60.0.0.6 : PSK "password"
-'''
+60.0.0.4 60.0.0.6 : PSK 0scGFzc3dvcmQ=
+''' % FAKE_VPNSERVICE_ID
 
 PLUTO_ACTIVE_STATUS = """000 "%(conn_id)s/0x1": erouted;\n
 000 #4: "%(conn_id)s/0x1":500 STATE_QUICK_R2 (IPsec SA established); \
@@ -328,13 +327,14 @@ class BaseIPsecDeviceDriver(base.BaseTestCase):
               vpnservice=FAKE_VPN_SERVICE):
         super(BaseIPsecDeviceDriver, self).setUp()
         for klass in [
-            'neutron.common.rpc.create_connection',
+            'neutron_lib.rpc.Connection',
             'oslo_service.loopingcall.FixedIntervalLoopingCall'
         ]:
             mock.patch(klass).start()
         self._execute = mock.patch.object(ipsec_process, '_execute').start()
         self.agent = mock.Mock()
         self.conf = cfg.CONF
+        l3_config.register_l3_agent_config_opts(l3_config.OPTS, self.conf)
         self.agent.conf = self.conf
         self.driver = driver(
             self.agent,
@@ -1018,6 +1018,7 @@ class TestOpenSwanConfigGeneration(BaseIPsecDeviceDriver):
         peer_ips = info.get('peers', ['60.0.0.5', '60.0.0.6'])
         virtual_privates.sort()
         return EXPECTED_OPENSWAN_CONF % {
+            'vpnservice_id': FAKE_VPNSERVICE_ID,
             'virtual_privates': ','.join(virtual_privates),
             'next_hop': next_hop,
             'local_cidrs1': local_cidrs[0], 'local_cidrs2': local_cidrs[1],
@@ -1099,6 +1100,7 @@ class IPsecStrongswanConfigGeneration(BaseIPsecDeviceDriver):
         peer_ips = info.get('peers', ['60.0.0.5', '60.0.0.6'])
         auth_mode = info.get('ipsec_auth', STRONGSWAN_AUTH_ESP)
         return EXPECTED_IPSEC_STRONGSWAN_CONF % {
+            'vpnservice_id': FAKE_VPNSERVICE_ID,
             'local_cidrs1': local_cidrs[0], 'local_cidrs2': local_cidrs[1],
             'peer_cidrs1': peer_cidrs[0], 'peer_cidrs2': peer_cidrs[1],
             'left': local_ip,
@@ -1454,9 +1456,8 @@ class TestLibreSwanProcess(base.BaseTestCase):
                                                        self.vpnservice,
                                                        mock.ANY)
 
-    @mock.patch('os.remove')
     @mock.patch('os.path.exists', return_value=True)
-    def test_ensure_configs_on_restart(self, exists_mock, remove_mock):
+    def test_ensure_configs_on_restart(self, exists_mock):
         openswan_ipsec.OpenSwanProcess.ensure_configs = mock.Mock()
         with mock.patch.object(
             self.ipsec_process, '_execute'
@@ -1466,14 +1467,18 @@ class TestLibreSwanProcess(base.BaseTestCase):
             self.ipsec_process, '_ensure_needed_files'
         ) as fake_ensure_needed_files:
             self.ipsec_process.ensure_configs()
-            expected = [mock.call(['chown', '--from=%s' % os.getuid(),
+
+            expected = [mock.call(['rm', '-f',
+                                   self.ipsec_process._get_config_filename(
+                                       'ipsec.secrets')]),
+                        mock.call(['chown', '--from=%s' % os.getuid(),
                                    'root:root',
                                    self.ipsec_process._get_config_filename(
                                        'ipsec.secrets')]),
                         mock.call(['chown', '--from=%s' % os.getuid(),
                                    'root:root', self.ipsec_process.log_dir])]
             fake_execute.assert_has_calls(expected)
-            self.assertEqual(2, fake_execute.call_count)
+            self.assertEqual(3, fake_execute.call_count)
 
             expected = [mock.call(['_stackmanager', 'start']),
                         mock.call(['checknss'])]
@@ -1482,11 +1487,9 @@ class TestLibreSwanProcess(base.BaseTestCase):
 
             self.assertTrue(fake_ensure_needed_files.called)
             self.assertTrue(exists_mock.called)
-            self.assertTrue(remove_mock.called)
 
-    @mock.patch('os.remove')
     @mock.patch('os.path.exists', return_value=False)
-    def test_ensure_configs(self, exists_mock, remove_mock):
+    def test_ensure_configs(self, exists_mock):
         openswan_ipsec.OpenSwanProcess.ensure_configs = mock.Mock()
         with mock.patch.object(
             self.ipsec_process, '_execute'
@@ -1513,10 +1516,8 @@ class TestLibreSwanProcess(base.BaseTestCase):
 
             self.assertTrue(fake_ensure_needed_files.called)
             self.assertTrue(exists_mock.called)
-            self.assertFalse(remove_mock.called)
 
         exists_mock.reset_mock()
-        remove_mock.reset_mock()
 
         with mock.patch.object(
             self.ipsec_process, '_execute'
@@ -1545,7 +1546,6 @@ class TestLibreSwanProcess(base.BaseTestCase):
 
             self.assertTrue(fake_ensure_needed_files.called)
             self.assertTrue(exists_mock.called)
-            self.assertFalse(remove_mock.called)
 
 
 class IPsecStrongswanDeviceDriverLegacy(IPSecDeviceLegacy):
@@ -1584,20 +1584,3 @@ class IPsecStrongswanDeviceDriverDVR(IPSecDeviceDVR):
               ipsec_process=strongswan_ipsec.StrongSwanProcess):
         super(IPsecStrongswanDeviceDriverDVR, self).setUp(driver,
                                                           ipsec_process)
-
-
-class IPsecFedoraStrongswanDeviceDriverLegacy(
-    IPsecStrongswanDeviceDriverLegacy):
-
-    def setUp(self, driver=fedora_strongswan_ipsec.FedoraStrongSwanDriver,
-              ipsec_process=fedora_strongswan_ipsec.FedoraStrongSwanProcess):
-        super(IPsecFedoraStrongswanDeviceDriverLegacy,
-              self).setUp(driver, ipsec_process)
-
-
-class IPsecFedoraStrongswanDeviceDriverDVR(IPSecDeviceDVR):
-
-    def setUp(self, driver=fedora_strongswan_ipsec.FedoraStrongSwanDriver,
-              ipsec_process=fedora_strongswan_ipsec.FedoraStrongSwanProcess):
-        super(IPsecFedoraStrongswanDeviceDriverDVR, self).setUp(driver,
-                                                                ipsec_process)
